@@ -5,4 +5,8 @@ from .ds_models import create_ds_models
 from .ds_io.reader_s3 import DsReaderS3
 from .ds_io.reader_fs import DsReaderFs
 from .ds_io.game_ds_loader import GameDsLoader
-from .tome import TomeCuratorFs
+from .tome import TomeCuratorFs, create_tome_curator
+from .exchange import (
+    create_dataexchange_dataset,
+    download_dataexchange_dataset_revision,
+)
